fn lvalue_is_state_var(gcx: Gcx<'_>, hir: &Hir<'_>, expr: &Expr<'_>) -> boolExpand description
Returns true if the lvalue expression ultimately writes to a storage variable.
Peels through index accesses, member accesses, and slices to find a state variable or an expression that returns a storage reference.